# Django Tools About

Simple Django app to manage company About secction

## Installation

1. Install with pip install `django-tools-about`.

2. Add `djtools.about` to your INSTALLED_APPS setting like this:
```
INSTALLED_APPS = [
    ...
    'djtools.about',
]
```
